@@ -175,19 +175,21 @@ mock_sysfs_init (MockSysfs *ms)
   ms->devices = g_hash_table_new (g_str_hash, g_str_equal);
 
   /* udev_enumerate_scan_devices() will return -ENOENT, if
-   * sys/bus or sys/class directories can not be found
+   * sys/bus or sys/class directories can not be found;
+   * fixed in https://github.com/martinpitt/umockdev/commit/5e8296014346
+   * but work with older versions as well
    */
   sys = umockdev_testbed_get_sys_dir (ms->bed);
 
   bus = g_build_filename (sys, "bus", NULL);
   r = g_mkdir (bus, 0744);
 
-  if (r < 0)
+  if (r < 0 && errno != EEXIST)
     g_warning ("could not create %s", bus);
 
   cls = g_build_filename (sys, "class", NULL);
   r = g_mkdir (cls, 0744);
-  if (r < 0)
+  if (r < 0 && errno != EEXIST)
     g_warning ("could not create %s", bus);
 }
 
@@ -772,7 +774,7 @@ mock_sysfs_domain_bootacl_set (MockSysfs  *ms,
   data = g_strjoinv (",", acl);
   path = g_build_filename (domain->path, "boot_acl", NULL);
 
-  ok = bolt_file_write_all (path, data, -1, error);
+  ok = bolt_file_write_all (path, data, strlen (data), error);
   if (!ok)
     return FALSE;
 
@@ -805,7 +807,7 @@ mock_syfs_domain_iommu_set (MockSysfs  *ms,
     }
 
   path = g_build_filename (domain->path, BOLT_SYSFS_IOMMU, NULL);
-  ok = bolt_file_write_all (path, val, -1, error);
+  ok = bolt_file_write_all (path, val, strlen (val), error);
   if (!ok)
     return FALSE;
 
